package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jun 15, 2023
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func PprofLisent(pprofAddr string)
PprofLisent 如果pprofAddr不为空则开启pprof
e.g : PprofLisent("127.0.0.1:16060")
Source Files
¶
Click to show internal directories.
Click to hide internal directories.